@@ -2,16 +2,19 @@ package core
 
 import (
 	"fmt"
-	"github.com/gocolly/colly/v2"
 	"io/ioutil"
 	"net/http"
 	"net/url"
 	"regexp"
 	"strings"
 	"sync"
+
+	jsoniter "github.com/json-iterator/go"
+
+	"github.com/gocolly/colly/v2"
 )
 
-func ParseRobots(site *url.URL, output *Output, c *colly.Collector, wg *sync.WaitGroup) {
+func ParseRobots(site *url.URL, crawler *Crawler, c *colly.Collector, wg *sync.WaitGroup) {
 	defer wg.Done()
 	robotsURL := site.String() + "/robots.txt"
 
@@ -31,14 +34,28 @@ func ParseRobots(site *url.URL, output *Output, c *colly.Collector, wg *sync.Wai
 		for _, line := range lines {
 			if strings.Contains(line, "llow: ") {
 				url := re.ReplaceAllString(line, "")
-				url = FixUrl(url, site)
+				url = FixUrl(site, url)
 				if url == "" {
 					continue
 				}
 				outputFormat := fmt.Sprintf("[robots] - %s", url)
+
+				if crawler.JsonOutput {
+					sout := SpiderOutput{
+						Input:      crawler.Input,
+						Source:     "robots",
+						OutputType: "url",
+						Output:     url,
+					}
+					if data, err := jsoniter.MarshalToString(sout); err == nil {
+						outputFormat = data
+					}
+				} else if crawler.Quiet {
+					outputFormat = url
+				}
 				fmt.Println(outputFormat)
-				if output != nil {
-					output.WriteToFile(outputFormat)
+				if crawler.Output != nil {
+					crawler.Output.WriteToFile(outputFormat)
 				}
 				_ = c.Visit(url)
 			}
